# coding: utf-8

# flake8: noqa

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# import apis into sdk package
from haplohub.api.metadata_api import MetadataApi
from haplohub.api.predictions_api import PredictionsApi
from haplohub.api.sample_api import SampleApi
from haplohub.api.default_api import DefaultApi

# import ApiClient
from haplohub.api_response import ApiResponse
from haplohub.api_client import ApiClient
from haplohub.configuration import Configuration
from haplohub.exceptions import OpenApiException
from haplohub.exceptions import ApiTypeError
from haplohub.exceptions import ApiValueError
from haplohub.exceptions import ApiKeyError
from haplohub.exceptions import ApiAttributeError
from haplohub.exceptions import ApiException

# import models into sdk package
from haplohub.models.accession_schema import AccessionSchema
from haplohub.models.error_response import ErrorResponse
from haplohub.models.error_schema import ErrorSchema
from haplohub.models.get_hgvs_response import GetHgvsResponse
from haplohub.models.get_prediction_response import GetPredictionResponse
from haplohub.models.get_prediction_results_response import GetPredictionResultsResponse
from haplohub.models.hgvs_dosage_schema import HgvsDosageSchema
from haplohub.models.paginated_response_accession_schema import PaginatedResponseAccessionSchema
from haplohub.models.paginated_response_prediction_schema import PaginatedResponsePredictionSchema
from haplohub.models.prediction_results_schema import PredictionResultsSchema
from haplohub.models.prediction_schema import PredictionSchema
from haplohub.models.prediction_status import PredictionStatus
from haplohub.models.response import Response
from haplohub.models.response1 import Response1
from haplohub.models.response2 import Response2
from haplohub.models.response3 import Response3
from haplohub.models.response_status import ResponseStatus
from haplohub.models.run_prediction_request import RunPredictionRequest
from haplohub.models.run_prediction_response import RunPredictionResponse
from haplohub.models.success_response import SuccessResponse



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401

from pydantic import BaseModel, Field, StrictInt, StrictStr


class AccessionSchema(BaseModel):
    """
    AccessionSchema
    """

    chromosome: StrictStr = Field(...)
    accession: StrictStr = Field(...)
    length: StrictInt = Field(...)
    build: StrictStr = Field(...)
    build_version: StrictStr = Field(...)
    __properties = ["chromosome", "accession", "length", "build", "build_version"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccessionSchema:
        """Create an instance of AccessionSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccessionSchema:
        """Create an instance of AccessionSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AccessionSchema.parse_obj(obj)

        _obj = AccessionSchema.parse_obj(
            {
                "chromosome": obj.get("chromosome"),
                "accession": obj.get("accession"),
                "length": obj.get("length"),
                "build": obj.get("build"),
                "build_version": obj.get("build_version"),
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

try:
    from ._version import __version__
except ImportError:
    __version__ = "0.0.0+unknown"

# import models into model package
from haplohub.models.accession_schema import AccessionSchema
from haplohub.models.error_response import ErrorResponse
from haplohub.models.error_schema import ErrorSchema
from haplohub.models.get_hgvs_response import GetHgvsResponse
from haplohub.models.get_prediction_response import GetPredictionResponse
from haplohub.models.get_prediction_results_response import GetPredictionResultsResponse
from haplohub.models.hgvs_dosage_schema import HgvsDosageSchema
from haplohub.models.paginated_response_accession_schema import PaginatedResponseAccessionSchema
from haplohub.models.paginated_response_prediction_schema import PaginatedResponsePredictionSchema
from haplohub.models.prediction_results_schema import PredictionResultsSchema
from haplohub.models.prediction_schema import PredictionSchema
from haplohub.models.prediction_status import PredictionStatus
from haplohub.models.response import Response
from haplohub.models.response1 import Response1
from haplohub.models.response2 import Response2
from haplohub.models.response3 import Response3
from haplohub.models.response_status import ResponseStatus
from haplohub.models.run_prediction_request import RunPredictionRequest
from haplohub.models.run_prediction_response import RunPredictionResponse
from haplohub.models.success_response import SuccessResponse



# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING, Any, List, Optional, Union

from pydantic import BaseModel, Field, ValidationError, validator

from haplohub.models.error_response import ErrorResponse
from haplohub.models.get_prediction_results_response import GetPredictionResultsResponse

RESPONSE3_ANY_OF_SCHEMAS = ["ErrorResponse", "GetPredictionResultsResponse"]


class Response3(BaseModel):
    """
    Response3
    """

    # data type: GetPredictionResultsResponse
    anyof_schema_1_validator: Optional[GetPredictionResultsResponse] = None
    # data type: ErrorResponse
    anyof_schema_2_validator: Optional[ErrorResponse] = None
    if TYPE_CHECKING:
        actual_instance: Union[ErrorResponse, GetPredictionResultsResponse]
    else:
        actual_instance: Any
    any_of_schemas: List[str] = Field(RESPONSE3_ANY_OF_SCHEMAS, const=True)

    class Config:
        validate_assignment = True

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @validator("actual_instance")
    def actual_instance_must_validate_anyof(cls, v):
        instance = Response3.construct()
        error_messages = []
        # validate data type: GetPredictionResultsResponse
        if not isinstance(v, GetPredictionResultsResponse):
            error_messages.append(f"Error! Input type `{type(v)}` is not `GetPredictionResultsResponse`")
        else:
            return v

        # validate data type: ErrorResponse
        if not isinstance(v, ErrorResponse):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ErrorResponse`")
        else:
            return v

        if error_messages:
            # no match
            raise ValueError(
                "No match found when setting the actual_instance in Response3 with anyOf schemas: ErrorResponse, GetPredictionResultsResponse. Details: "
                + ", ".join(error_messages)
            )
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> Response3:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Response3:
        """Returns the object represented by the json string"""
        instance = Response3.construct()
        error_messages = []
        # anyof_schema_1_validator: Optional[GetPredictionResultsResponse] = None
        try:
            instance.actual_instance = GetPredictionResultsResponse.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # anyof_schema_2_validator: Optional[ErrorResponse] = None
        try:
            instance.actual_instance = ErrorResponse.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if error_messages:
            # no match
            raise ValueError(
                "No match found when deserializing the JSON string into Response3 with anyOf schemas: ErrorResponse, GetPredictionResultsResponse. Details: "
                + ", ".join(error_messages)
            )
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.dict())



# flake8: noqa

# import apis into api package
from haplohub.api.metadata_api import MetadataApi
from haplohub.api.predictions_api import PredictionsApi
from haplohub.api.sample_api import SampleApi
from haplohub.api.default_api import DefaultApi
